@@ -4,9 +4,10 @@
 #' Transform 'HUMAnN' metagenomic results to microtable object, reference: Franzosa et al. (2018) <doi:10.1038/s41592-018-0176-y>.
 #' @param abund_table 'HUMAnN' output abundance table, see the example.
 #' @param db default "MetaCyc"; either "MetaCyc" or "KEGG"; the pathway database used in the abund_table file generation.
-#' @param sample_data default NULL; the sample metadata table, must be tab or comma seperated file, generally, a file with suffix "tsv" or "csv"..
+#' @param sample_data default NULL; the sample metadata table, must be tab or comma seperated file, generally, a file with suffix "tsv" or "csv".
 #' @param match_table default NULL; a two column table used to replace the sample names in 'HUMAnN abundance result; Remember just two columns with no column names;
 #'    The first column must be sample names used in abund_table, the second column is the new sample names, e.g. the rownames in sample_table. See the example files.
+#' @param ... parameter passed to microtable$new function of microeco package, such as auto_tidy parameter.
 #' @return microtable object.
 #' @examples
 #' \donttest{
@@ -56,14 +57,14 @@
 #' humann2meco(abund_table = abund_file_path, db = "KEGG")
 #' test <- humann2meco(abund_table = abund_file_path, db = "KEGG", 
 #'   sample_data = sample_file_path, match_table = match_file_path)
-#' test$tax_table %<>% subset(level1 != "unclassified")
+#' test$tax_table %<>% subset(Level.1 != "unclassified")
 #' test$tidy_dataset()
 #' # rel = FALSE donot use relative abundance
 #' test$cal_abund(select_cols = 1:3, rel = FALSE)
-#' test1 <- trans_abund$new(test, taxrank = "level2", ntaxa = 10)
+#' test1 <- trans_abund$new(test, taxrank = "Level.2", ntaxa = 10)
 #' test1$plot_bar(facet = "Group", ylab_title = "Abundance (RPK)")
 #' # select both function and taxa
-#' test$cal_abund(select_cols = c("level1", "Phylum", "Genus"), rel = TRUE)
+#' test$cal_abund(select_cols = c("Level.1", "Phylum", "Genus"), rel = TRUE)
 #' test1 <- trans_abund$new(test, taxrank = "Phylum", ntaxa = 10, delete_part_prefix = TRUE)
 #' test1$plot_bar(facet = "Group")
 #' # functional biomarker
@@ -76,7 +77,7 @@
 #' test1$plot_lefse_bar(LDA_score = 2)
 #' }
 #' @export
-humann2meco <- function(abund_table, db = c("MetaCyc", "KEGG")[1], sample_data = NULL, match_table = NULL){
+humann2meco <- function(abund_table, db = c("MetaCyc", "KEGG")[1], sample_data = NULL, match_table = NULL, ...){
 	# first check func_data file format.
 	abund_raw <- read.delim(abund_table, check.names = FALSE, row.names = 1, stringsAsFactors = FALSE)
 
@@ -131,13 +132,12 @@ humann2meco <- function(abund_table, db = c("MetaCyc", "KEGG")[1], sample_data =
 		if(grepl("KEGG", db, ignore.case = TRUE)){
 			data("Tax4Fun2_KEGG", envir=environment(), package = "microeco")
 			ko_mapping_file <- Tax4Fun2_KEGG$ptw_desc
-			colnames(ko_mapping_file) <- c("pathway", "level3", "level2", "level1")
-			ko_mapping_file%<>% .[, c(1, 4, 3, 2)]
+			ko_mapping_file$pathway <- rownames(ko_mapping_file)
 
 			tax_table <- tax_table %>%
 				dplyr::left_join(., ko_mapping_file, by = c("Func" = "pathway")) %>%
 				dplyr::left_join(., CHOCOPhlAn_taxonomy, by = c("Genus" = "Genus")) %>%
-				.[, c("level1", "level2", "level3", "Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")]
+				.[, c("Level.1", "Level.2", "Level.3", "Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")]
 
 		}else{
 			stop("Unknown db provided! Must be either MetaCyc or KEGG !")
@@ -161,6 +161,6 @@ humann2meco <- function(abund_table, db = c("MetaCyc", "KEGG")[1], sample_data =
 		sample_data <- check_sample_table(sample_data = sample_data)
 	}
 
-	dataset <- microtable$new(otu_table = abund_new, sample_table = sample_data, tax_table = tax_table)
+	dataset <- microtable$new(otu_table = abund_new, sample_table = sample_data, tax_table = tax_table, ...)
 	dataset
 }
